#
# spec file for package python-pycha
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pycha
Version:        0.8.1
Release:        5.4
Summary:        A library for making charts with Python
License:        LGPL-3.0-or-later
URL:            https://github.com/timesong/pycha
Source:         https://files.pythonhosted.org/packages/source/p/pycha/pycha-%{version}.tar.gz
# is safe_unicode() needed at all?
Patch0:         python-pycha-no-six.patch
# PATCH-FIX-OPENSUSE remove makeSuite calls
Patch1:         remove-makesuite.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cairocffi
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module cairocffi}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Pycha is a Python package for drawing charts using the Cairo library.
It will not try to draw any possible chart on Earth, but draw the
most common ones nicely. Pycha is based on the Plotr which is based on
PlotKit, both of which are written in JavaScript and are for client
web programming. Pycha was developed for the server side.

%prep
%autosetup -p1 -n pycha-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/chavier
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative chavier

%postun
%python_uninstall_alternative chavier

%check
%pytest tests/*.py

%files %{python_files}
%doc README.txt CHANGES.txt AUTHORS
%license COPYING
%{python_sitelib}/pycha
%{python_sitelib}/pycha-%{version}.dist-info
%{python_sitelib}/chavier
%python_alternative %{_bindir}/chavier

%changelog
* Wed Nov 27 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-makesuite.patch:
  * Do not use testsuite.makeSuite to construct the testsuite.
- Switch to pyproject macros.
- Update URL.
* Sun Jan 14 2024 Axel Braun <axel.braun@gmx.de>
- enabled %%{?sle15_python_module_pythons}
* Tue Apr 11 2023 pgajdos@suse.com
- do not require python-six
- added patches
  + python-pycha-no-six.patch
- test the package
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.8.1
  * Forgot to update Changelog for 0.8.0
- Update to 0.8.0
  * Add support for Python 3 by encukou
  * Add support for Tox, Pyflakes, Coverage and Buildbucket pipelines
  * Remove support for Buildout
* Wed Apr  3 2019 John Vandenberg <jayvdb@gmail.com>
- Fix fdupes to avoid python3 package egg-info being symlinks into
  the python2 package which may not be installed.
- Use %%license
* Mon May 29 2017 axel.braun@gmx.de
- added python-rpm-macros
* Sun May 28 2017 okurz@suse.com
- Convert to singlespec
* Fri Sep 23 2016 jengelh@inai.de
- Update license field; trim description.
* Sun Aug 21 2016 axel.braun@gmx.de
- link to pypi.io
* Thu Jun 30 2016 axel.braun@gmx.de
- release 0.7.0
  Initial build on OBS
